@@ -894,10 +894,6 @@ create_callback (GObject      *source_object,
 	ret = bluetooth_client_setup_device_finish (BLUETOOTH_CLIENT (source_object),
 						    res, &path, &error);
 
-	g_clear_pointer (&priv->pairing_dialog, gtk_widget_destroy);
-
-	g_hash_table_remove (priv->pairing_devices, path);
-
 	/* Create failed */
 	if (ret == FALSE) {
 		//char *text;
@@ -915,10 +911,10 @@ create_callback (GObject      *source_object,
 		if (g_strcmp0 (dbus_error, "org.bluez.Error.AuthenticationCanceled") != 0) {
 			//FIXME show an error?
 			/* translators:
-			 * The '%s' is the device name, for example:
-			 * Setting up 'Sony Bluetooth Headset' failed
+			 * The “%s” is the device name, for example:
+			 * Setting up “Sony Bluetooth Headset” failed
 			 */
-			//text = g_strdup_printf(_("Setting up '%s' failed"), target_name);
+			//text = g_strdup_printf(_("Setting up “%s” failed"), target_name);
 
 			g_warning ("Setting up %s failed: %s", path, error->message);
 
@@ -934,6 +930,10 @@ create_callback (GObject      *source_object,
 
 	priv = BLUETOOTH_SETTINGS_WIDGET_GET_PRIVATE (user_data);
 
+	g_clear_pointer (&priv->pairing_dialog, gtk_widget_destroy);
+
+	g_hash_table_remove (priv->pairing_devices, path);
+
 	bluetooth_client_set_trusted (BLUETOOTH_CLIENT (source_object), path, TRUE);
 
 	data = g_new0 (SetupConnectData, 1);
@@ -1238,7 +1238,7 @@ update_visibility (BluetoothSettingsWidget *self)
 		g_free (path);
 
 		/* translators: first %s is the name of the computer, for example:
-		 * Visible as “Bastien Nocera's Computer” followed by the
+		 * Visible as “Bastien Nocera’s Computer” followed by the
 		 * location of the Downloads folder.*/
 		label = g_strdup_printf (_("Visible as “%s” and available for Bluetooth file transfers. Transferred files are placed in the <a href=\"%s\">Downloads</a> folder."), name, uri);
 		g_free (uri);
@@ -1267,7 +1267,7 @@ show_confirm_dialog (BluetoothSettingsWidget *self,
 
 	dialog = gtk_message_dialog_new (GTK_WINDOW (priv->properties_dialog), GTK_DIALOG_MODAL,
 					 GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE,
-					 _("Remove '%s' from the list of devices?"), name);
+					 _("Remove “%s” from the list of devices?"), name);
 	g_object_set (G_OBJECT (dialog), "secondary-text",
 		      _("If you remove the device, you will have to set it up again before next use."),
 		      NULL);
@@ -1513,14 +1513,12 @@ add_device_section (BluetoothSettingsWidget *self)
 	vbox = WID ("vbox_bluetooth");
 
 	box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-	gtk_widget_set_margin_start (box, 128);
-	gtk_widget_set_margin_end (box, 128);
 	gtk_widget_set_margin_top (box, 6);
 	gtk_widget_set_margin_bottom (box, 24);
 	gtk_box_pack_start (GTK_BOX (vbox), box, TRUE, TRUE, 0);
 	priv->child_box = box;
 
-	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 	gtk_box_pack_start (GTK_BOX (box), hbox, FALSE, TRUE, 0);
 
 	s = g_markup_printf_escaped ("<b>%s</b>", _("Devices"));
@@ -1528,9 +1526,8 @@ add_device_section (BluetoothSettingsWidget *self)
 	g_free (s);
 	gtk_label_set_use_markup (GTK_LABEL (widget), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (widget), 0, 0.5);
-	gtk_widget_set_margin_start (widget, 6);
 	gtk_widget_set_margin_end (widget, 6);
-	gtk_widget_set_margin_bottom (widget, 6);
+	gtk_widget_set_margin_bottom (widget, 12);
 	gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, TRUE, 0);
 
 	/* Discoverable spinner */
@@ -1538,7 +1535,7 @@ add_device_section (BluetoothSettingsWidget *self)
 	g_object_bind_property (G_OBJECT (priv->client), "default-adapter-discovering",
 				G_OBJECT (priv->device_spinner), "active",
 				G_BINDING_SYNC_CREATE);
-	gtk_widget_set_margin_bottom (spinner, 6);
+	gtk_widget_set_margin_bottom (spinner, 12);
 	gtk_box_pack_start (GTK_BOX (hbox), spinner, FALSE, TRUE, 0);
 
 	/* Discoverable label placeholder, the real name is set in update_visibility().
